Module resample

Module resample 

Resample an existing candle stream from a finer timeframe to a coarser one.

Structs

Resampler
Roll a stream of candles up to a coarser timeframe.

Functions

resample_all
Roll an entire iterator of candles into a Vec of coarser candles. The final open bar (if any) is appended via Resampler::flush.