pub fn resample_all<I>(timeframe: Timeframe, iter: I) -> Result<Vec<Candle>>Expand description
Roll an entire iterator of candles into a Vec of coarser candles. The final
open bar (if any) is appended via Resampler::flush.
pub fn resample_all<I>(timeframe: Timeframe, iter: I) -> Result<Vec<Candle>>Roll an entire iterator of candles into a Vec of coarser candles. The final
open bar (if any) is appended via Resampler::flush.