pub struct KlineEvent {
pub symbol: String,
pub interval: Interval,
pub candle: Candle,
pub is_closed: bool,
}Available on crate feature
live-binance only.Expand description
One push from the Binance kline stream.
Fields
symbol: StringSymbol in lowercase form as sent by Binance (e.g. "btcusdt").
interval: IntervalInterval the candle belongs to.
candle: CandleCandle in its current state (may still be open).
is_closed: boolWhether the candle has been closed by the server. Closed events are the only ones safe to use for bar-completion logic.